@@ -1,14 +1,17 @@
 package POEx::ZMQ3::Publisher;
-$POEx::ZMQ3::Publisher::VERSION = '0.071';
+{
+  $POEx::ZMQ3::Publisher::VERSION = '0.060001';
+}
+
 use Carp;
+use Moo;
 use POE;
 
+use namespace::clean;
 
-use Moo;
 with 'POEx::ZMQ3::Role::Emitter';
 
-
-sub build_defined_states { [] }
+sub build_defined_states {[]}
 
 sub start {
   my ($self, @endpoints) = @_;
@@ -44,11 +47,9 @@ sub publish_multipart {
 
 =pod
 
-=for Pod::Coverage build_defined_states
-
 =head1 NAME
 
-POEx::ZMQ3::Publisher
+POEx::ZMQ3::Publisher - A PUB-type ZeroMQ socket
 
 =head1 SYNOPSIS
 
