@@ -1,13 +1,16 @@
 package POEx::ZMQ3::Requestor;
-$POEx::ZMQ3::Requestor::VERSION = '0.071';
+{
+  $POEx::ZMQ3::Requestor::VERSION = '0.060001';
+}
+
 use Carp;
+use Moo;
 use POE;
 
+use namespace::clean;
 
-use Moo;
 with 'POEx::ZMQ3::Role::Emitter';
 
-
 has targets => (
   is => 'ro',
   default => sub { [] },
@@ -73,11 +76,9 @@ sub zmqsock_recv {
 
 =pod
 
-=for Pod::Coverage build_defined_states emitter_started zmqsock.+
-
 =head1 NAME
 
-POEx::ZMQ3::Requestor
+POEx::ZMQ3::Requestor - A REQ-type ZeroMQ socket
 
 =head1 SYNOPSIS
 
@@ -157,12 +158,6 @@ Emitted when we are initialized; $_[ARG0] is the target REP server's address.
 
 Emitted when we receive a reply to a request; $_[ARG0] is the raw data.
 
-=head2 Attributes
-
-=head3 targets
-
-An ARRAY of endpoints the Requestor was configured with; see L</start>.
-
 =head1 SEE ALSO
 
 L<POEx::ZMQ3>
