@@ -1,12 +1,13 @@
 package POEx::ZMQ3::Sockets;
-$POEx::ZMQ3::Sockets::VERSION = '0.071';
-use v5.10;
+{
+  $POEx::ZMQ3::Sockets::VERSION = '0.060001';
+}
+
+use 5.10.1;
 use Carp;
-
+use Moo;
 use POE;
-use POSIX ();
-
-use MooX::Role::Pluggable::Constants;
+require POSIX;
 
 use ZMQ::LibZMQ3;
 use ZMQ::Constants 
@@ -38,14 +39,12 @@ use ZMQ::Constants
  ;
 
 
+with 'MooX::Role::POE::Emitter';
+use MooX::Role::Pluggable::Constants;
+
 require POEx::ZMQ3::Sockets::ZMQSocket;
 sub ZMQSocket () { 'POEx::ZMQ3::Sockets::ZMQSocket' }
 
-
-use Moo;
-with 'MooX::Role::POE::Emitter';
-
-
 require POEx::ZMQ3::Context;
 has context => (
   is      => 'ro',
@@ -209,13 +208,6 @@ sub _zpub_connect {
   $self->emit( 'connect_added', $alias, $endpt )
 }
 
-#sub monitor {
-  # FIXME
-  #  Call zmq_socket_monitor (if we have it)
-  #  Talk to our own inproc:// monitor socket (module for same?)
-  #  Translate to POE events (provide monitor as an emitter?)
-  #  Return monitor socket instance?
-#}
 
 sub write {
   my $self = shift;
@@ -278,14 +270,11 @@ sub _zsock_write {
 
   my $rc;
   if ( $rc = zmq_msg_send( $data, $struct->zsock, ($flags ? $flags : ()) ) 
-      && ($rc // 0) == -1 ) {
+      && ($rc//0) == -1 ) {
 
     unless ($rc == POSIX::EAGAIN || $rc == POSIX::EINTR) {
       confess "zmq_msg_send failed; $!";
     }
-
-    # FIXME provide higher-level HWM interface(s),
-    #  manage struct->buffer appropriately?
   } else {
     ## Successfully queued on socket.
     shift @{ $struct->buffer }
@@ -416,8 +405,7 @@ sub _zsock_watch {
 sub _zsock_unwatch {
   my ($kernel, $self, $alias) = @_[KERNEL, OBJECT, ARG0];
   my $struct = $self->_zmq_sockets->{$alias};
-  ## There is a race condition in some ZMQ versions that results in 'bad FD'
-  ## assertions when exiting; deferred destruction helps:
+  ## Deferred destruction eliminates 'bad FD' at exit.
   $self->yield(sub { $_[KERNEL]->select( $struct->handle ) });
   $self->yield(sub { delete $_[OBJECT]->_zmq_sockets->{$alias} });
 }
@@ -443,11 +431,9 @@ sub _zmq_clear_all {
 
 =pod
 
-=for Pod::Coverage BUILD ZMQSocket emitter_\w+
-
 =head1 NAME
 
-POEx::ZMQ3::Sockets
+POEx::ZMQ3::Sockets - POE ZeroMQ Component
 
 =head1 SYNOPSIS
 
@@ -494,7 +480,7 @@ POEx::ZMQ3::Sockets
 
     if ($data eq 'PONG') {
       ## Got a PONG. Send another PING:
-      $heap->{zmq}->write( 'pinger', 'PING' );
+      $zmq->write( 'pinger', 'PING' );
     }
   }
 
@@ -502,8 +488,6 @@ POEx::ZMQ3::Sockets
 
 =head1 DESCRIPTION
 
-B<< This software is deprecated and known-broken; see L<POEx::ZMQ> instead! >>
-
 This is the backend L<MooX::Role::POE::Emitter> session behind L<POEx::ZMQ3>,
 integrating ZeroMQ (L<http://www.zeromq.org>) with a L<POE> event loop.
 
