@@ -1,18 +1,14 @@
 package POEx::ZMQ3::Sockets::ZMQSocket;
-$POEx::ZMQ3::Sockets::ZMQSocket::VERSION = '0.071';
-=pod
+{
+  $POEx::ZMQ3::Sockets::ZMQSocket::VERSION = '0.060001';
+}
 
-=for comment 
 
-Internal to POEx::ZMQ3::Sockets:
+## Internal to POEx::ZMQ3::Sockets.
 
-=for Pod::Coverage .*
-
-=cut
 
 use 5.10.1;
 use Carp;
-
 use Moo;
 
 has is_closing => (
